@@ -484,7 +484,7 @@ if (!array_key_exists($page, $allowed_pages)) {
                 }
 
                 // Apply initial theme on page load
-                const initialTheme = html.getAttribute('data-theme') || 'dark';
+                const initialTheme = document.documentElement.getAttribute('data-theme') || 'dark';
                 applyTheme(initialTheme);
 
                 // Listen for system theme changes if using auto mode
